@@ -4,8 +4,6 @@ This module provides transform classes for resizing operations, including unifor
 scaling with aspect ratio preservation, and size-constrained transformations.
 """
 
-from __future__ import annotations
-
 from collections.abc import Sequence
 from typing import Any, Literal, cast
 
@@ -16,7 +14,7 @@ from pydantic import Field, field_validator, model_validator
 from typing_extensions import Self
 
 from albumentations.core.transforms_interface import BaseTransformInitSchema, DualTransform
-from albumentations.core.type_definitions import ALL_TARGETS
+from albumentations.core.type_definitions import ALL_TARGETS, ImageType
 from albumentations.core.utils import to_tuple
 
 from . import functional as fgeometric
@@ -476,7 +474,10 @@ class LongestMaxSize(MaxSizeTransform):
         uint8, float32
 
     Note:
-        - If the longest side of the image is already equal to max_size, the image will not be resized.
+        - This transform scales images based on their longest side:
+            * If the longest side is **smaller** than max_size: the image will be **upscaled** (scale > 1.0)
+            * If the longest side is **equal** to max_size: the image will **not be resized** (scale = 1.0)
+            * If the longest side is **larger** than max_size: the image will be **downscaled** (scale < 1.0)
         - This transform will not crop the image. The resulting image may be smaller than specified in both dimensions.
         - For non-square images, both sides will be scaled proportionally to maintain the aspect ratio.
         - Bounding boxes and keypoints are scaled accordingly.
@@ -593,7 +594,10 @@ class SmallestMaxSize(MaxSizeTransform):
         uint8, float32
 
     Note:
-        - If the smallest side of the image is already equal to max_size, the image will not be resized.
+        - This transform scales images based on their smallest side:
+            * If the smallest side is **smaller** than max_size: the image will be **upscaled** (scale > 1.0)
+            * If the smallest side is **equal** to max_size: the image will **not be resized** (scale = 1.0)
+            * If the smallest side is **larger** than max_size: the image will be **downscaled** (scale < 1.0)
         - This transform will not crop the image. The resulting image may be larger than specified in both dimensions.
         - For non-square images, both sides will be scaled proportionally to maintain the aspect ratio.
         - Bounding boxes and keypoints are scaled accordingly.
@@ -812,7 +816,7 @@ class Resize(DualTransform):
         self.mask_interpolation = mask_interpolation
         self.area_for_downscale = area_for_downscale
 
-    def apply(self, img: np.ndarray, **params: Any) -> np.ndarray:
+    def apply(self, img: ImageType, **params: Any) -> ImageType:
         height, width = img.shape[:2]
         is_downscale = (self.height < height) or (self.width < width)
 
