@@ -7,9 +7,7 @@ such as spatial dimensions, apply dropout effects, and perform symmetry operatio
 interface and implements specific 3D augmentation logic.
 """
 
-from __future__ import annotations
-
-from typing import Annotated, Any, Literal, Union, cast
+from typing import Annotated, Any, Literal, cast
 
 import numpy as np
 from pydantic import AfterValidator, field_validator, model_validator
@@ -20,7 +18,7 @@ from albumentations.augmentations.transforms3d import functional as f3d
 from albumentations.core.keypoints_utils import KeypointsProcessor
 from albumentations.core.pydantic import check_range_bounds, nondecreasing
 from albumentations.core.transforms_interface import BaseTransformInitSchema, Transform3D
-from albumentations.core.type_definitions import Targets
+from albumentations.core.type_definitions import Targets, VolumeType
 
 __all__ = [
     "CenterCrop3D",
@@ -173,7 +171,7 @@ class BasePad3D(Transform3D):
         return f3d.pad_3d_with_params(
             volume=mask3d,
             padding=padding,
-            value=cast("Union[tuple[float, ...], float]", self.fill_mask),
+            value=cast("tuple[float, ...] | float", self.fill_mask),
         )
 
     def apply_to_keypoints(self, keypoints: np.ndarray, **params: Any) -> np.ndarray:
@@ -730,7 +728,7 @@ class BaseCropAndPad3D(Transform3D):
             return f3d.pad_3d_with_params(
                 cropped,
                 padding=padding,
-                value=cast("Union[tuple[float, ...], float]", self.fill_mask),
+                value=cast("tuple[float, ...] | float", self.fill_mask),
             )
 
         return cropped
@@ -1256,7 +1254,7 @@ class CoarseDropout3D(Transform3D):
 
         return {"holes": holes}
 
-    def apply_to_volume(self, volume: np.ndarray, holes: np.ndarray, **params: Any) -> np.ndarray:
+    def apply_to_volume(self, volume: VolumeType, holes: np.ndarray, **params: Any) -> VolumeType:
         """Apply dropout to a 3D volume.
 
         Args:
@@ -1400,7 +1398,7 @@ class CubicSymmetry(Transform3D):
         volume_shape = data["volume"].shape
         return {"index": self.py_random.randint(0, 47), "volume_shape": volume_shape}
 
-    def apply_to_volume(self, volume: np.ndarray, index: int, **params: Any) -> np.ndarray:
+    def apply_to_volume(self, volume: VolumeType, index: int, **params: Any) -> VolumeType:
         """Apply cubic symmetry transformation to a 3D volume.
 
         Args:
