@@ -7,11 +7,10 @@ other functions in the codebase. These utilities help ensure consistent behavior
 and simplify common operations across different augmentation transforms.
 """
 
-from __future__ import annotations
-
 import functools
+from collections.abc import Callable
 from functools import wraps
-from typing import Any, Callable, TypeVar, cast
+from typing import Any, Concatenate, TypeVar, cast
 
 import cv2
 import numpy as np
@@ -20,7 +19,7 @@ from albucore.utils import (
     is_multispectral_image,
     is_rgb_image,
 )
-from typing_extensions import Concatenate, ParamSpec
+from typing_extensions import ParamSpec
 
 from albumentations.core.keypoints_utils import angle_to_2pi_range
 
