@@ -7,12 +7,10 @@ The interfaces handle parameter validation, random state management, target type
 and serialization capabilities that are inherited by concrete transform implementations.
 """
 
-from __future__ import annotations
-
 import random
-from collections.abc import Sequence
+from collections.abc import Callable, Sequence
 from copy import deepcopy
-from typing import Any, Callable
+from typing import Any
 from warnings import warn
 
 import cv2
@@ -25,7 +23,7 @@ from albumentations.core.keypoints_utils import KeypointsProcessor
 from albumentations.core.validation import ValidatedTransformMeta
 
 from .serialization import Serializable, SerializableMeta, get_shortest_class_fullname
-from .type_definitions import ALL_TARGETS, Targets
+from .type_definitions import ALL_TARGETS, ImageType, Targets, VolumeType
 from .utils import ensure_contiguous_output, format_args
 
 __all__ = ["BasicTransform", "DualTransform", "ImageOnlyTransform", "NoOp", "Transform3D"]
@@ -69,6 +67,10 @@ class BasicTransform(Serializable, metaclass=CombinedMeta):
         applied_in_replay (bool, optional): Whether the transform was applied in replay.
         p (float): Probability of applying the transform.
 
+    Note:
+        The base class methods use *args to allow subclasses to add specific named parameters
+        (e.g., def apply(self, img, gamma, **params) is a valid override of apply(self, img, *args, **params)).
+
     """
 
     _targets: tuple[Targets, ...] | Targets  # targets that this transform can work on
@@ -314,7 +316,7 @@ class BasicTransform(Serializable, metaclass=CombinedMeta):
                 res[key] = arg
         return res
 
-    def set_deterministic(self, flag: bool, save_key: str = "replay") -> BasicTransform:
+    def set_deterministic(self, flag: bool, save_key: str = "replay") -> "BasicTransform":
         """Set transform to be deterministic."""
         if save_key == "params":
             msg = "params save_key is reserved"
@@ -335,7 +337,7 @@ class BasicTransform(Serializable, metaclass=CombinedMeta):
         state.update(self.get_transform_init_args())
         return f"{self.__class__.__name__}({format_args(state)})"
 
-    def apply(self, img: np.ndarray, *args: Any, **params: Any) -> np.ndarray:
+    def apply(self, img: ImageType, *args: Any, **params: Any) -> ImageType:
         """Apply transform on image."""
         raise NotImplementedError
 
@@ -357,16 +359,16 @@ class BasicTransform(Serializable, metaclass=CombinedMeta):
         transformed = np.stack([self.apply(image, **params) for image in images])
         return np.require(transformed, requirements=["C_CONTIGUOUS"])
 
-    def apply_to_volume(self, volume: np.ndarray, *args: Any, **params: Any) -> np.ndarray:
+    def apply_to_volume(self, volume: VolumeType, *args: Any, **params: Any) -> VolumeType:
         """Apply transform slice by slice to a volume.
 
         Args:
-            volume (np.ndarray): Input volume of shape (depth, height, width) or (depth, height, width, channels)
+            volume (VolumeType): Input volume of shape (depth, height, width) or (depth, height, width, channels)
             *args (Any): Additional positional arguments
             **params (Any): Additional parameters specific to the transform
 
         Returns:
-            np.ndarray: Transformed volume as numpy array in the same format as input
+            VolumeType: Transformed volume as numpy array in the same format as input
 
         """
         return self.apply_to_images(volume, *args, **params)
@@ -700,7 +702,7 @@ class DualTransform(BasicTransform):
 
     @batch_transform("spatial")
     def apply_to_mask3d(self, mask3d: np.ndarray, *args: Any, **params: Any) -> np.ndarray:
-        return self.apply_to_mask(mask3d, **params)
+        return self.apply_to_mask(mask3d, *args, **params)
 
     @batch_transform("spatial")
     def apply_to_masks3d(self, masks3d: np.ndarray, *args: Any, **params: Any) -> np.ndarray:
@@ -945,13 +947,13 @@ class NoOp(DualTransform):
     def apply_to_bboxes(self, bboxes: np.ndarray, **params: Any) -> np.ndarray:
         return bboxes
 
-    def apply(self, img: np.ndarray, **params: Any) -> np.ndarray:
+    def apply(self, img: ImageType, **params: Any) -> ImageType:
         return img
 
     def apply_to_mask(self, mask: np.ndarray, **params: Any) -> np.ndarray:
         return mask
 
-    def apply_to_volume(self, volume: np.ndarray, **params: Any) -> np.ndarray:
+    def apply_to_volume(self, volume: VolumeType, **params: Any) -> VolumeType:
         return volume
 
     def apply_to_volumes(self, volumes: np.ndarray, **params: Any) -> np.ndarray:
@@ -978,7 +980,7 @@ class Transform3D(DualTransform):
         keypoints: 3D numpy array of shape (N, 3)
     """
 
-    def apply_to_volume(self, volume: np.ndarray, *args: Any, **params: Any) -> np.ndarray:
+    def apply_to_volume(self, volume: VolumeType, *args: Any, **params: Any) -> VolumeType:
         """Apply transform to single 3D volume."""
         raise NotImplementedError
 
